"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var React = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeGestureHandler = require("react-native-gesture-handler");

var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));

var _constants = require("./constants");

var _Gridlines = _interopRequireDefault(require("./Gridlines"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function createBoundsValues(initialBounds) {
  return {
    topY: (0, _reactNativeReanimated.useSharedValue)(initialBounds.topY),
    bottomY: (0, _reactNativeReanimated.useSharedValue)(initialBounds.bottomY),
    leftX: (0, _reactNativeReanimated.useSharedValue)(initialBounds.leftX),
    rightX: (0, _reactNativeReanimated.useSharedValue)(initialBounds.rightX)
  };
}

function EditBox({
  gridlines = true,
  maxWidth,
  maxHeight,
  source
}, ref) {
  const aspectRatio = source.width / source.height;
  let imageWidth = (undefined !== maxWidth ? Math.min(maxWidth, source.width) : source.width) - 2 * _constants.BOX_BORDER;
  let imageHeight = imageWidth / aspectRatio;

  if (undefined !== maxHeight && imageHeight + 2 * _constants.BOX_BORDER > maxHeight) {
    imageHeight = maxHeight - 2 * _constants.BOX_BORDER;
    imageWidth = imageHeight * aspectRatio;
  }

  const initialBounds = {
    topY: -_constants.BOX_INDICATOR_BORDER + _constants.BOX_BORDER,
    bottomY: imageHeight - _constants.BOX_INDICATOR_SIZE + _constants.BOX_INDICATOR_BORDER + _constants.BOX_BORDER,
    leftX: -_constants.BOX_INDICATOR_BORDER + _constants.BOX_BORDER,
    rightX: imageWidth - _constants.BOX_INDICATOR_SIZE + _constants.BOX_INDICATOR_BORDER + _constants.BOX_BORDER
  };
  const isActive = (0, _reactNativeReanimated.useSharedValue)(false);
  const rotationZ = (0, _reactNativeReanimated.useSharedValue)(0);
  const rotationY = (0, _reactNativeReanimated.useSharedValue)(0);
  const scale = (0, _reactNativeReanimated.useSharedValue)(1);
  const currentBounds = createBoundsValues(initialBounds);
  const boundingBoxRect = createBoundsValues(initialBounds);

  const resetBoundingBox = () => {
    boundingBoxRect.topY.value = (0, _reactNativeReanimated.withTiming)(initialBounds.topY);
    boundingBoxRect.bottomY.value = (0, _reactNativeReanimated.withTiming)(initialBounds.bottomY);
    boundingBoxRect.leftX.value = (0, _reactNativeReanimated.withTiming)(initialBounds.leftX);
    boundingBoxRect.rightX.value = (0, _reactNativeReanimated.withTiming)(initialBounds.rightX);
  };

  const resetCurrentBounds = () => {
    currentBounds.topY.value = initialBounds.topY;
    currentBounds.bottomY.value = initialBounds.bottomY;
    currentBounds.leftX.value = initialBounds.leftX;
    currentBounds.rightX.value = initialBounds.rightX;
  };

  const handleOnReset = () => {
    resetCurrentBounds();
    resetBoundingBox();
    rotationZ.value = (0, _reactNativeReanimated.withTiming)(0);
    scale.value = (0, _reactNativeReanimated.withTiming)(1);
  };

  const handleOnRotate = degrees => {
    const isOriginalOrientation = degrees % 180 === 0;
    let nextScale = isOriginalOrientation ? 1 : aspectRatio; // Check if scaled and rotated height doesnt exceed max height

    if (undefined !== maxHeight && imageWidth * nextScale > maxHeight) {
      nextScale = maxHeight / imageWidth;
    }

    rotationZ.value = (0, _reactNativeReanimated.withTiming)(degrees);
    scale.value = (0, _reactNativeReanimated.withTiming)(nextScale);

    if (isOriginalOrientation) {
      resetBoundingBox();
      resetCurrentBounds();
      return;
    }

    const horizontal = imageWidth * nextScale - imageHeight;
    const vertical = imageHeight * nextScale - imageWidth;
    const topY = initialBounds.topY - horizontal / 2;
    const bottomY = initialBounds.bottomY + horizontal / 2;
    const leftX = initialBounds.leftX - vertical / 2;
    const rightX = initialBounds.rightX + vertical / 2;
    boundingBoxRect.topY.value = (0, _reactNativeReanimated.withTiming)(topY);
    boundingBoxRect.bottomY.value = (0, _reactNativeReanimated.withTiming)(bottomY);
    boundingBoxRect.leftX.value = (0, _reactNativeReanimated.withTiming)(leftX);
    boundingBoxRect.rightX.value = (0, _reactNativeReanimated.withTiming)(rightX);
    currentBounds.topY.value = topY;
    currentBounds.bottomY.value = bottomY;
    currentBounds.leftX.value = leftX;
    currentBounds.rightX.value = rightX;
  };

  React.useImperativeHandle(ref, () => ({
    calculateAdjustments: () => {
      const rotate = rotationZ.value;
      const indicatorSpace = _constants.BOX_INDICATOR_SIZE - 2 * _constants.BOX_INDICATOR_BORDER;
      const viewBoxWidth = boundingBoxRect.rightX.value - boundingBoxRect.leftX.value + indicatorSpace;
      const viewBoxHeight = boundingBoxRect.bottomY.value - boundingBoxRect.topY.value + indicatorSpace;
      const viewOriginX = boundingBoxRect.leftX.value - currentBounds.leftX.value;
      const viewOriginY = boundingBoxRect.topY.value - currentBounds.topY.value;
      let actualBoxWidth = viewBoxWidth / imageWidth * source.width;
      let actualBoxHeight = viewBoxHeight / imageHeight * source.height;

      if (!(rotate % 180 === 0)) {
        const scaledWidth = imageHeight * scale.value;
        const scaledHeight = imageWidth * scale.value;
        actualBoxHeight = viewBoxHeight / scaledHeight * source.width;
        actualBoxWidth = viewBoxWidth / scaledWidth * source.height;
      }

      return {
        rotate,
        flipHorizontal: rotationY.value === 180,
        originX: viewOriginX / viewBoxWidth * actualBoxWidth,
        originY: viewOriginY / viewBoxHeight * actualBoxHeight,
        width: actualBoxWidth,
        height: actualBoxHeight
      };
    },
    flip: () => {
      rotationY.value = (rotationY.value + 180) % 360;
    },
    reset: handleOnReset,
    rotate: handleOnRotate
  }));
  const gestureHandler = (0, _reactNativeReanimated.useAnimatedGestureHandler)({
    onStart: (event, context) => {
      isActive.value = true;
      context.topY = boundingBoxRect.topY.value;
      context.bottomY = boundingBoxRect.bottomY.value;
      context.leftX = boundingBoxRect.leftX.value;
      context.rightX = boundingBoxRect.rightX.value;
      const boxWidth = boundingBoxRect.rightX.value - boundingBoxRect.leftX.value;
      const boxHeight = boundingBoxRect.bottomY.value - boundingBoxRect.topY.value;
      context.verticalMode = event.y <= 1 / 3 * boxHeight ? "top" : event.y >= 2 / 3 * boxHeight ? "bottom" : null;
      context.horizontalMode = event.x <= 1 / 3 * boxWidth ? "left" : event.x >= 2 / 3 * boxWidth ? "right" : null;
    },
    onActive: (event, context) => {
      if (context.verticalMode === "top") {
        boundingBoxRect.topY.value = Math.min(Math.max(currentBounds.topY.value, context.topY + event.translationY), currentBounds.bottomY.value);
      } else if (context.verticalMode === "bottom") {
        boundingBoxRect.bottomY.value = Math.max(Math.min(currentBounds.bottomY.value, context.bottomY + event.translationY), currentBounds.topY.value);
      }

      if (context.horizontalMode === "left") {
        boundingBoxRect.leftX.value = Math.min(Math.max(currentBounds.leftX.value, context.leftX + event.translationX), currentBounds.rightX.value);
      } else if (context.horizontalMode === "right") {
        boundingBoxRect.rightX.value = Math.max(Math.min(currentBounds.rightX.value, context.rightX + event.translationX), currentBounds.leftX.value);
      }
    },
    onFinish: () => {
      isActive.value = false;
    }
  });
  const backgroundImageStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    transform: [{
      scale: scale.value
    }, {
      rotateZ: `${rotationZ.value}deg`
    }, {
      rotateY: `${rotationY.value}deg`
    }]
  }));
  const foregroundImageStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    top: -boundingBoxRect.topY.value + initialBounds.topY,
    left: -boundingBoxRect.leftX.value + initialBounds.leftX,
    transform: [{
      scale: scale.value
    }, {
      rotateZ: `${rotationZ.value}deg`
    }, {
      rotateY: `${rotationY.value}deg`
    }]
  }));
  const boundingBoxStyles = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    top: boundingBoxRect.topY.value - initialBounds.topY,
    left: boundingBoxRect.leftX.value - initialBounds.leftX,
    bottom: initialBounds.bottomY - boundingBoxRect.bottomY.value,
    right: initialBounds.rightX - boundingBoxRect.rightX.value
  }));
  const foregroundImageBoxStyles = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    top: boundingBoxRect.topY.value - initialBounds.topY,
    left: boundingBoxRect.leftX.value - initialBounds.leftX,
    bottom: initialBounds.bottomY - boundingBoxRect.bottomY.value,
    right: initialBounds.rightX - boundingBoxRect.rightX.value
  }));
  const imageDimensions = {
    height: imageHeight,
    width: imageWidth
  };
  return /*#__PURE__*/React.createElement(_reactNative.View, {
    style: {
      height: imageHeight + 2 * _constants.BOX_BORDER,
      width: imageWidth + 2 * _constants.BOX_BORDER
    }
  }, /*#__PURE__*/React.createElement(_reactNativeReanimated.default.Image, {
    source: source,
    style: [styles.image, styles.backgroundImage, imageDimensions, backgroundImageStyle]
  }), /*#__PURE__*/React.createElement(_reactNativeReanimated.default.View, {
    style: [styles.imageBoundingBox, foregroundImageBoxStyles]
  }, /*#__PURE__*/React.createElement(_reactNativeReanimated.default.Image, {
    source: source,
    style: [styles.image, imageDimensions, foregroundImageStyle]
  }), gridlines && /*#__PURE__*/React.createElement(_Gridlines.default, {
    topY: boundingBoxRect.topY,
    bottomY: boundingBoxRect.bottomY,
    leftX: boundingBoxRect.leftX,
    rightX: boundingBoxRect.rightX,
    isActive: isActive
  })), /*#__PURE__*/React.createElement(_reactNativeGestureHandler.PanGestureHandler, {
    onGestureEvent: gestureHandler
  }, /*#__PURE__*/React.createElement(_reactNativeReanimated.default.View, {
    style: [styles.boundingBox, boundingBoxStyles]
  }, /*#__PURE__*/React.createElement(_reactNativeReanimated.default.View, {
    style: [styles.indicator, styles.indicatorTopLeft]
  }), /*#__PURE__*/React.createElement(_reactNativeReanimated.default.View, {
    style: [styles.indicator, styles.indicatorTopRight]
  }), /*#__PURE__*/React.createElement(_reactNativeReanimated.default.View, {
    style: [styles.indicator, styles.indicatorBottomLeft]
  }), /*#__PURE__*/React.createElement(_reactNativeReanimated.default.View, {
    style: [styles.indicator, styles.indicatorBottomRight]
  }))));
}

const styles = _reactNative.StyleSheet.create({
  boundingBox: {
    borderColor: "white",
    borderWidth: _constants.BOX_BORDER,
    position: "absolute"
  },
  imageBoundingBox: {
    borderColor: "transparent",
    borderWidth: _constants.BOX_BORDER,
    position: "absolute",
    overflow: "hidden"
  },
  backgroundImage: {
    opacity: 0.25
  },
  image: { ..._reactNative.StyleSheet.absoluteFillObject,
    top: _constants.BOX_BORDER,
    left: _constants.BOX_BORDER
  },
  indicator: {
    position: "absolute",
    height: _constants.BOX_INDICATOR_SIZE,
    width: _constants.BOX_INDICATOR_SIZE
  },
  indicatorTopLeft: {
    borderTopColor: "white",
    borderTopWidth: _constants.BOX_INDICATOR_BORDER,
    borderStartColor: "white",
    borderStartWidth: _constants.BOX_INDICATOR_BORDER,
    top: -_constants.BOX_INDICATOR_BORDER,
    left: -_constants.BOX_INDICATOR_BORDER
  },
  indicatorTopRight: {
    borderTopColor: "white",
    borderTopWidth: _constants.BOX_INDICATOR_BORDER,
    borderEndColor: "white",
    borderEndWidth: _constants.BOX_INDICATOR_BORDER,
    top: -_constants.BOX_INDICATOR_BORDER,
    right: -_constants.BOX_INDICATOR_BORDER
  },
  indicatorBottomLeft: {
    borderBottomColor: "white",
    borderBottomWidth: _constants.BOX_INDICATOR_BORDER,
    borderStartColor: "white",
    borderStartWidth: _constants.BOX_INDICATOR_BORDER,
    bottom: -_constants.BOX_INDICATOR_BORDER,
    left: -_constants.BOX_INDICATOR_BORDER
  },
  indicatorBottomRight: {
    borderBottomColor: "white",
    borderBottomWidth: _constants.BOX_INDICATOR_BORDER,
    borderEndColor: "white",
    borderEndWidth: _constants.BOX_INDICATOR_BORDER,
    bottom: -_constants.BOX_INDICATOR_BORDER,
    right: -_constants.BOX_INDICATOR_BORDER
  }
});

var _default = /*#__PURE__*/React.forwardRef(EditBox);

exports.default = _default;
//# sourceMappingURL=EditBox.js.map