"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = EditScreen;

var React = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _EditBox = _interopRequireDefault(require("./EditBox"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const {
  width: SCREEN_WIDTH,
  height: SCREEN_HEIGHT
} = _reactNative.Dimensions.get("screen");

const PADDING_HORIZONTAL = 15;
const BOX_WIDTH = SCREEN_WIDTH - PADDING_HORIZONTAL * 2;

function EditScreen({
  onCancel,
  onDone,
  source,
  useBackgroundCover = true
}) {
  const editBoxRef = React.useRef(null);
  const rotation = React.useRef(0);

  const handleOnCancel = () => {
    onCancel === null || onCancel === void 0 ? void 0 : onCancel();
  };

  const handleOnDone = () => {
    if (!editBoxRef.current) return;
    onDone === null || onDone === void 0 ? void 0 : onDone(editBoxRef.current.calculateAdjustments());
  };

  const handleOnFlip = () => {
    var _editBoxRef$current;

    (_editBoxRef$current = editBoxRef.current) === null || _editBoxRef$current === void 0 ? void 0 : _editBoxRef$current.flip();
  };

  const handleOnReset = () => {
    var _editBoxRef$current2;

    (_editBoxRef$current2 = editBoxRef.current) === null || _editBoxRef$current2 === void 0 ? void 0 : _editBoxRef$current2.reset();
    rotation.current = 0;
  };

  const handleOnRotate = () => {
    var _editBoxRef$current3;

    const newValue = (rotation.current + 90) % 360;
    (_editBoxRef$current3 = editBoxRef.current) === null || _editBoxRef$current3 === void 0 ? void 0 : _editBoxRef$current3.rotate(newValue);
    rotation.current = newValue;
  };

  return /*#__PURE__*/React.createElement(_reactNative.View, {
    style: styles.page
  }, useBackgroundCover && /*#__PURE__*/React.createElement(_reactNative.Image, {
    blurRadius: 28,
    resizeMode: "cover",
    source: source,
    style: styles.backgroundCover
  }), /*#__PURE__*/React.createElement(_reactNative.SafeAreaView, {
    style: styles.safeArea
  }, /*#__PURE__*/React.createElement(_reactNative.StatusBar, {
    barStyle: "light-content"
  }), /*#__PURE__*/React.createElement(_reactNative.View, {
    style: styles.safeArea
  }, /*#__PURE__*/React.createElement(_reactNative.View, {
    style: styles.content
  }, /*#__PURE__*/React.createElement(_EditBox.default, {
    ref: editBoxRef,
    maxHeight: SCREEN_HEIGHT * 0.7,
    maxWidth: BOX_WIDTH,
    source: { ...source
    }
  })), /*#__PURE__*/React.createElement(_reactNative.View, {
    style: styles.primaryButtons
  }, /*#__PURE__*/React.createElement(_reactNative.Pressable, {
    onPress: handleOnRotate
  }, /*#__PURE__*/React.createElement(_reactNative.Text, {
    style: styles.resetText
  }, "Rotate")), /*#__PURE__*/React.createElement(_reactNative.Pressable, {
    onPress: handleOnFlip
  }, /*#__PURE__*/React.createElement(_reactNative.Text, {
    style: styles.resetText
  }, "Flip")), /*#__PURE__*/React.createElement(_reactNative.Pressable, {
    onPress: handleOnReset
  }, /*#__PURE__*/React.createElement(_reactNative.Text, {
    style: styles.resetText
  }, "Reset"))), /*#__PURE__*/React.createElement(_reactNative.View, {
    style: styles.bottomButtons
  }, undefined !== onCancel ? /*#__PURE__*/React.createElement(_reactNative.Pressable, {
    onPress: handleOnCancel
  }, /*#__PURE__*/React.createElement(_reactNative.Text, {
    style: styles.bottomButtonText
  }, "Cancel")) : /*#__PURE__*/React.createElement(_reactNative.View, null), /*#__PURE__*/React.createElement(_reactNative.Pressable, {
    onPress: handleOnDone
  }, /*#__PURE__*/React.createElement(_reactNative.Text, {
    style: styles.bottomButtonText
  }, "Done"))))));
}

const styles = _reactNative.StyleSheet.create({
  backgroundCover: { ..._reactNative.StyleSheet.absoluteFillObject,
    bottom: 50,
    width: SCREEN_WIDTH,
    height: "95%",
    opacity: 0.1
  },
  bottomButtons: {
    backgroundColor: "rgb(56, 56, 56)",
    flexDirection: "row",
    justifyContent: "space-between",
    paddingHorizontal: PADDING_HORIZONTAL,
    paddingVertical: 10
  },
  bottomButtonText: {
    color: "white",
    fontSize: 16,
    fontWeight: "700"
  },
  container: {
    flex: 1
  },
  content: {
    alignItems: "center",
    justifyContent: "center",
    flex: 1
  },
  primaryButtons: {
    alignItems: "center",
    flexDirection: "row",
    justifyContent: "space-between",
    paddingHorizontal: PADDING_HORIZONTAL,
    paddingBottom: 10
  },
  resetText: {
    color: "white",
    fontSize: 16
  },
  page: {
    backgroundColor: "rgb(56, 56, 56)",
    flex: 1
  },
  safeArea: {
    flex: 1
  }
});
//# sourceMappingURL=EditScreen.js.map