import * as React from "react";
import { Dimensions, Image, Pressable, SafeAreaView, StatusBar, StyleSheet, Text, View } from "react-native";
import EditBox from "./EditBox";
const {
  width: SCREEN_WIDTH,
  height: SCREEN_HEIGHT
} = Dimensions.get("screen");
const PADDING_HORIZONTAL = 15;
const BOX_WIDTH = SCREEN_WIDTH - PADDING_HORIZONTAL * 2;
export default function EditScreen({
  onCancel,
  onDone,
  source,
  useBackgroundCover = true
}) {
  const editBoxRef = React.useRef(null);
  const rotation = React.useRef(0);

  const handleOnCancel = () => {
    onCancel === null || onCancel === void 0 ? void 0 : onCancel();
  };

  const handleOnDone = () => {
    if (!editBoxRef.current) return;
    onDone === null || onDone === void 0 ? void 0 : onDone(editBoxRef.current.calculateAdjustments());
  };

  const handleOnFlip = () => {
    var _editBoxRef$current;

    (_editBoxRef$current = editBoxRef.current) === null || _editBoxRef$current === void 0 ? void 0 : _editBoxRef$current.flip();
  };

  const handleOnReset = () => {
    var _editBoxRef$current2;

    (_editBoxRef$current2 = editBoxRef.current) === null || _editBoxRef$current2 === void 0 ? void 0 : _editBoxRef$current2.reset();
    rotation.current = 0;
  };

  const handleOnRotate = () => {
    var _editBoxRef$current3;

    const newValue = (rotation.current + 90) % 360;
    (_editBoxRef$current3 = editBoxRef.current) === null || _editBoxRef$current3 === void 0 ? void 0 : _editBoxRef$current3.rotate(newValue);
    rotation.current = newValue;
  };

  return /*#__PURE__*/React.createElement(View, {
    style: styles.page
  }, useBackgroundCover && /*#__PURE__*/React.createElement(Image, {
    blurRadius: 28,
    resizeMode: "cover",
    source: source,
    style: styles.backgroundCover
  }), /*#__PURE__*/React.createElement(SafeAreaView, {
    style: styles.safeArea
  }, /*#__PURE__*/React.createElement(StatusBar, {
    barStyle: "light-content"
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.safeArea
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.content
  }, /*#__PURE__*/React.createElement(EditBox, {
    ref: editBoxRef,
    maxHeight: SCREEN_HEIGHT * 0.7,
    maxWidth: BOX_WIDTH,
    source: { ...source
    }
  })), /*#__PURE__*/React.createElement(View, {
    style: styles.primaryButtons
  }, /*#__PURE__*/React.createElement(Pressable, {
    onPress: handleOnRotate
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.resetText
  }, "Rotate")), /*#__PURE__*/React.createElement(Pressable, {
    onPress: handleOnFlip
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.resetText
  }, "Flip")), /*#__PURE__*/React.createElement(Pressable, {
    onPress: handleOnReset
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.resetText
  }, "Reset"))), /*#__PURE__*/React.createElement(View, {
    style: styles.bottomButtons
  }, undefined !== onCancel ? /*#__PURE__*/React.createElement(Pressable, {
    onPress: handleOnCancel
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.bottomButtonText
  }, "Cancel")) : /*#__PURE__*/React.createElement(View, null), /*#__PURE__*/React.createElement(Pressable, {
    onPress: handleOnDone
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.bottomButtonText
  }, "Done"))))));
}
const styles = StyleSheet.create({
  backgroundCover: { ...StyleSheet.absoluteFillObject,
    bottom: 50,
    width: SCREEN_WIDTH,
    height: "95%",
    opacity: 0.1
  },
  bottomButtons: {
    backgroundColor: "rgb(56, 56, 56)",
    flexDirection: "row",
    justifyContent: "space-between",
    paddingHorizontal: PADDING_HORIZONTAL,
    paddingVertical: 10
  },
  bottomButtonText: {
    color: "white",
    fontSize: 16,
    fontWeight: "700"
  },
  container: {
    flex: 1
  },
  content: {
    alignItems: "center",
    justifyContent: "center",
    flex: 1
  },
  primaryButtons: {
    alignItems: "center",
    flexDirection: "row",
    justifyContent: "space-between",
    paddingHorizontal: PADDING_HORIZONTAL,
    paddingBottom: 10
  },
  resetText: {
    color: "white",
    fontSize: 16
  },
  page: {
    backgroundColor: "rgb(56, 56, 56)",
    flex: 1
  },
  safeArea: {
    flex: 1
  }
});
//# sourceMappingURL=EditScreen.js.map